# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20045ResponseUsages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'uncategorized': 'InlineResponse20045ResponseUncategorized',
        'documents_spreadsheets_and_text_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'temporary_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'backup_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'archive_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'audio_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'disk_images': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'installers': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'image_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'log_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'email_data': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'server_virtualization': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles',
        'video_files': 'InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles'
    }

    attribute_map = {
        'uncategorized': 'Uncategorized',
        'documents_spreadsheets_and_text_files': 'Documents Spreadsheets and text files',
        'temporary_files': 'Temporary files',
        'backup_files': 'Backup files',
        'archive_files': 'Archive files',
        'audio_files': 'Audio files',
        'disk_images': 'Disk Images',
        'installers': 'Installers',
        'image_files': 'Image files',
        'log_files': 'Log Files',
        'email_data': 'Email Data',
        'server_virtualization': 'Server Virtualization',
        'video_files': 'Video files'
    }

    def __init__(self, uncategorized=None, documents_spreadsheets_and_text_files=None, temporary_files=None, backup_files=None, archive_files=None, audio_files=None, disk_images=None, installers=None, image_files=None, log_files=None, email_data=None, server_virtualization=None, video_files=None, _configuration=None):  # noqa: E501
        """InlineResponse20045ResponseUsages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._uncategorized = None
        self._documents_spreadsheets_and_text_files = None
        self._temporary_files = None
        self._backup_files = None
        self._archive_files = None
        self._audio_files = None
        self._disk_images = None
        self._installers = None
        self._image_files = None
        self._log_files = None
        self._email_data = None
        self._server_virtualization = None
        self._video_files = None
        self.discriminator = None

        if uncategorized is not None:
            self.uncategorized = uncategorized
        if documents_spreadsheets_and_text_files is not None:
            self.documents_spreadsheets_and_text_files = documents_spreadsheets_and_text_files
        if temporary_files is not None:
            self.temporary_files = temporary_files
        if backup_files is not None:
            self.backup_files = backup_files
        if archive_files is not None:
            self.archive_files = archive_files
        if audio_files is not None:
            self.audio_files = audio_files
        if disk_images is not None:
            self.disk_images = disk_images
        if installers is not None:
            self.installers = installers
        if image_files is not None:
            self.image_files = image_files
        if log_files is not None:
            self.log_files = log_files
        if email_data is not None:
            self.email_data = email_data
        if server_virtualization is not None:
            self.server_virtualization = server_virtualization
        if video_files is not None:
            self.video_files = video_files

    @property
    def uncategorized(self):
        """Gets the uncategorized of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The uncategorized of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseUncategorized
        """
        return self._uncategorized

    @uncategorized.setter
    def uncategorized(self, uncategorized):
        """Sets the uncategorized of this InlineResponse20045ResponseUsages.


        :param uncategorized: The uncategorized of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseUncategorized
        """

        self._uncategorized = uncategorized

    @property
    def documents_spreadsheets_and_text_files(self):
        """Gets the documents_spreadsheets_and_text_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The documents_spreadsheets_and_text_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._documents_spreadsheets_and_text_files

    @documents_spreadsheets_and_text_files.setter
    def documents_spreadsheets_and_text_files(self, documents_spreadsheets_and_text_files):
        """Sets the documents_spreadsheets_and_text_files of this InlineResponse20045ResponseUsages.


        :param documents_spreadsheets_and_text_files: The documents_spreadsheets_and_text_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._documents_spreadsheets_and_text_files = documents_spreadsheets_and_text_files

    @property
    def temporary_files(self):
        """Gets the temporary_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The temporary_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._temporary_files

    @temporary_files.setter
    def temporary_files(self, temporary_files):
        """Sets the temporary_files of this InlineResponse20045ResponseUsages.


        :param temporary_files: The temporary_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._temporary_files = temporary_files

    @property
    def backup_files(self):
        """Gets the backup_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The backup_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._backup_files

    @backup_files.setter
    def backup_files(self, backup_files):
        """Sets the backup_files of this InlineResponse20045ResponseUsages.


        :param backup_files: The backup_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._backup_files = backup_files

    @property
    def archive_files(self):
        """Gets the archive_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The archive_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._archive_files

    @archive_files.setter
    def archive_files(self, archive_files):
        """Sets the archive_files of this InlineResponse20045ResponseUsages.


        :param archive_files: The archive_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._archive_files = archive_files

    @property
    def audio_files(self):
        """Gets the audio_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The audio_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._audio_files

    @audio_files.setter
    def audio_files(self, audio_files):
        """Sets the audio_files of this InlineResponse20045ResponseUsages.


        :param audio_files: The audio_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._audio_files = audio_files

    @property
    def disk_images(self):
        """Gets the disk_images of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The disk_images of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._disk_images

    @disk_images.setter
    def disk_images(self, disk_images):
        """Sets the disk_images of this InlineResponse20045ResponseUsages.


        :param disk_images: The disk_images of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._disk_images = disk_images

    @property
    def installers(self):
        """Gets the installers of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The installers of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._installers

    @installers.setter
    def installers(self, installers):
        """Sets the installers of this InlineResponse20045ResponseUsages.


        :param installers: The installers of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._installers = installers

    @property
    def image_files(self):
        """Gets the image_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The image_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._image_files

    @image_files.setter
    def image_files(self, image_files):
        """Sets the image_files of this InlineResponse20045ResponseUsages.


        :param image_files: The image_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._image_files = image_files

    @property
    def log_files(self):
        """Gets the log_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The log_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._log_files

    @log_files.setter
    def log_files(self, log_files):
        """Sets the log_files of this InlineResponse20045ResponseUsages.


        :param log_files: The log_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._log_files = log_files

    @property
    def email_data(self):
        """Gets the email_data of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The email_data of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._email_data

    @email_data.setter
    def email_data(self, email_data):
        """Sets the email_data of this InlineResponse20045ResponseUsages.


        :param email_data: The email_data of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._email_data = email_data

    @property
    def server_virtualization(self):
        """Gets the server_virtualization of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The server_virtualization of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._server_virtualization

    @server_virtualization.setter
    def server_virtualization(self, server_virtualization):
        """Sets the server_virtualization of this InlineResponse20045ResponseUsages.


        :param server_virtualization: The server_virtualization of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._server_virtualization = server_virtualization

    @property
    def video_files(self):
        """Gets the video_files of this InlineResponse20045ResponseUsages.  # noqa: E501


        :return: The video_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :rtype: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """
        return self._video_files

    @video_files.setter
    def video_files(self, video_files):
        """Sets the video_files of this InlineResponse20045ResponseUsages.


        :param video_files: The video_files of this InlineResponse20045ResponseUsages.  # noqa: E501
        :type: InlineResponse20045ResponseDocumentsSpreadsheetsAndTextFiles
        """

        self._video_files = video_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20045ResponseUsages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20045ResponseUsages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20045ResponseUsages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class SetTicketSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message_id': 'str',
        'expiration_date': 'str',
        'priority': 'str',
        'zsnap': 'str',
        'to_user': 'str',
        'rate_limit': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'message_id': 'message_id',
        'expiration_date': 'expiration_date',
        'priority': 'priority',
        'zsnap': 'zsnap',
        'to_user': 'to_user',
        'rate_limit': 'rate_limit',
        'comment': 'comment'
    }

    def __init__(self, message_id=None, expiration_date=None, priority=None, zsnap=None, to_user=None, rate_limit=None, comment=None, _configuration=None):  # noqa: E501
        """SetTicketSettings - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._message_id = None
        self._expiration_date = None
        self._priority = None
        self._zsnap = None
        self._to_user = None
        self._rate_limit = None
        self._comment = None
        self.discriminator = None

        self.message_id = message_id
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if priority is not None:
            self.priority = priority
        if zsnap is not None:
            self.zsnap = zsnap
        if to_user is not None:
            self.to_user = to_user
        if rate_limit is not None:
            self.rate_limit = rate_limit
        self.comment = comment

    @property
    def message_id(self):
        """Gets the message_id of this SetTicketSettings.  # noqa: E501

        Message id up to 120 characters  # noqa: E501

        :return: The message_id of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this SetTicketSettings.

        Message id up to 120 characters  # noqa: E501

        :param message_id: The message_id of this SetTicketSettings.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and message_id is None:
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def expiration_date(self):
        """Gets the expiration_date of this SetTicketSettings.  # noqa: E501

        Support ticket suppression expiration date and time (UTC)  # noqa: E501

        :return: The expiration_date of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this SetTicketSettings.

        Support ticket suppression expiration date and time (UTC)  # noqa: E501

        :param expiration_date: The expiration_date of this SetTicketSettings.  # noqa: E501
        :type: str
        """

        self._expiration_date = expiration_date

    @property
    def priority(self):
        """Gets the priority of this SetTicketSettings.  # noqa: E501

        Support ticket priority (empty string for default)  # noqa: E501

        :return: The priority of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this SetTicketSettings.

        Support ticket priority (empty string for default)  # noqa: E501

        :param priority: The priority of this SetTicketSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["low", "normal", "high", "urgent"]  # noqa: E501
        if (self._configuration.client_side_validation and
                priority not in allowed_values):
            raise ValueError(
                "Invalid value for `priority` ({0}), must be one of {1}"  # noqa: E501
                .format(priority, allowed_values)
            )

        self._priority = priority

    @property
    def zsnap(self):
        """Gets the zsnap of this SetTicketSettings.  # noqa: E501

        Support ticket zsnap (empty string for default)  # noqa: E501

        :return: The zsnap of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._zsnap

    @zsnap.setter
    def zsnap(self, zsnap):
        """Sets the zsnap of this SetTicketSettings.

        Support ticket zsnap (empty string for default)  # noqa: E501

        :param zsnap: The zsnap of this SetTicketSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["yes", "no", "lite"]  # noqa: E501
        if (self._configuration.client_side_validation and
                zsnap not in allowed_values):
            raise ValueError(
                "Invalid value for `zsnap` ({0}), must be one of {1}"  # noqa: E501
                .format(zsnap, allowed_values)
            )

        self._zsnap = zsnap

    @property
    def to_user(self):
        """Gets the to_user of this SetTicketSettings.  # noqa: E501

        Support ticket send to users (empty string for default)  # noqa: E501

        :return: The to_user of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._to_user

    @to_user.setter
    def to_user(self, to_user):
        """Sets the to_user of this SetTicketSettings.

        Support ticket send to users (empty string for default)  # noqa: E501

        :param to_user: The to_user of this SetTicketSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["yes", "no"]  # noqa: E501
        if (self._configuration.client_side_validation and
                to_user not in allowed_values):
            raise ValueError(
                "Invalid value for `to_user` ({0}), must be one of {1}"  # noqa: E501
                .format(to_user, allowed_values)
            )

        self._to_user = to_user

    @property
    def rate_limit(self):
        """Gets the rate_limit of this SetTicketSettings.  # noqa: E501

        Rate limit must be at least 1  # noqa: E501

        :return: The rate_limit of this SetTicketSettings.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """Sets the rate_limit of this SetTicketSettings.

        Rate limit must be at least 1  # noqa: E501

        :param rate_limit: The rate_limit of this SetTicketSettings.  # noqa: E501
        :type: int
        """

        self._rate_limit = rate_limit

    @property
    def comment(self):
        """Gets the comment of this SetTicketSettings.  # noqa: E501

        Comment text up to 120 characters  # noqa: E501

        :return: The comment of this SetTicketSettings.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SetTicketSettings.

        Comment text up to 120 characters  # noqa: E501

        :param comment: The comment of this SetTicketSettings.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and comment is None:
            raise ValueError("Invalid value for `comment`, must not be `None`")  # noqa: E501

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetTicketSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetTicketSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SetTicketSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200100CapacityTrend(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'used': 'list[float]',
        'dates': 'InlineResponse200100CapacityTrendDates',
        'categories': 'list[str]',
        'total': 'list[float]',
        'metadata': 'list[float]'
    }

    attribute_map = {
        'used': 'used',
        'dates': 'dates',
        'categories': 'categories',
        'total': 'total',
        'metadata': 'metadata'
    }

    def __init__(self, used=None, dates=None, categories=None, total=None, metadata=None, _configuration=None):  # noqa: E501
        """InlineResponse200100CapacityTrend - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._used = None
        self._dates = None
        self._categories = None
        self._total = None
        self._metadata = None
        self.discriminator = None

        if used is not None:
            self.used = used
        if dates is not None:
            self.dates = dates
        if categories is not None:
            self.categories = categories
        if total is not None:
            self.total = total
        if metadata is not None:
            self.metadata = metadata

    @property
    def used(self):
        """Gets the used of this InlineResponse200100CapacityTrend.  # noqa: E501


        :return: The used of this InlineResponse200100CapacityTrend.  # noqa: E501
        :rtype: list[float]
        """
        return self._used

    @used.setter
    def used(self, used):
        """Sets the used of this InlineResponse200100CapacityTrend.


        :param used: The used of this InlineResponse200100CapacityTrend.  # noqa: E501
        :type: list[float]
        """

        self._used = used

    @property
    def dates(self):
        """Gets the dates of this InlineResponse200100CapacityTrend.  # noqa: E501


        :return: The dates of this InlineResponse200100CapacityTrend.  # noqa: E501
        :rtype: InlineResponse200100CapacityTrendDates
        """
        return self._dates

    @dates.setter
    def dates(self, dates):
        """Sets the dates of this InlineResponse200100CapacityTrend.


        :param dates: The dates of this InlineResponse200100CapacityTrend.  # noqa: E501
        :type: InlineResponse200100CapacityTrendDates
        """

        self._dates = dates

    @property
    def categories(self):
        """Gets the categories of this InlineResponse200100CapacityTrend.  # noqa: E501


        :return: The categories of this InlineResponse200100CapacityTrend.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this InlineResponse200100CapacityTrend.


        :param categories: The categories of this InlineResponse200100CapacityTrend.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def total(self):
        """Gets the total of this InlineResponse200100CapacityTrend.  # noqa: E501


        :return: The total of this InlineResponse200100CapacityTrend.  # noqa: E501
        :rtype: list[float]
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this InlineResponse200100CapacityTrend.


        :param total: The total of this InlineResponse200100CapacityTrend.  # noqa: E501
        :type: list[float]
        """

        self._total = total

    @property
    def metadata(self):
        """Gets the metadata of this InlineResponse200100CapacityTrend.  # noqa: E501


        :return: The metadata of this InlineResponse200100CapacityTrend.  # noqa: E501
        :rtype: list[float]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this InlineResponse200100CapacityTrend.


        :param metadata: The metadata of this InlineResponse200100CapacityTrend.  # noqa: E501
        :type: list[float]
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200100CapacityTrend, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200100CapacityTrend):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200100CapacityTrend):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200106ResponseRemoteVpsaFeatures(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'wan_optimization': 'str',
        'manual_snaps': 'str',
        'reconnect_policies': 'str',
        'archival_pool': 'str',
        'afa': 'str'
    }

    attribute_map = {
        'wan_optimization': 'wan_optimization',
        'manual_snaps': 'manual_snaps',
        'reconnect_policies': 'reconnect_policies',
        'archival_pool': 'archival_pool',
        'afa': 'afa'
    }

    def __init__(self, wan_optimization=None, manual_snaps=None, reconnect_policies=None, archival_pool=None, afa=None, _configuration=None):  # noqa: E501
        """InlineResponse200106ResponseRemoteVpsaFeatures - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._wan_optimization = None
        self._manual_snaps = None
        self._reconnect_policies = None
        self._archival_pool = None
        self._afa = None
        self.discriminator = None

        if wan_optimization is not None:
            self.wan_optimization = wan_optimization
        if manual_snaps is not None:
            self.manual_snaps = manual_snaps
        if reconnect_policies is not None:
            self.reconnect_policies = reconnect_policies
        if archival_pool is not None:
            self.archival_pool = archival_pool
        if afa is not None:
            self.afa = afa

    @property
    def wan_optimization(self):
        """Gets the wan_optimization of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501


        :return: The wan_optimization of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._wan_optimization

    @wan_optimization.setter
    def wan_optimization(self, wan_optimization):
        """Sets the wan_optimization of this InlineResponse200106ResponseRemoteVpsaFeatures.


        :param wan_optimization: The wan_optimization of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._wan_optimization = wan_optimization

    @property
    def manual_snaps(self):
        """Gets the manual_snaps of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501


        :return: The manual_snaps of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._manual_snaps

    @manual_snaps.setter
    def manual_snaps(self, manual_snaps):
        """Sets the manual_snaps of this InlineResponse200106ResponseRemoteVpsaFeatures.


        :param manual_snaps: The manual_snaps of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._manual_snaps = manual_snaps

    @property
    def reconnect_policies(self):
        """Gets the reconnect_policies of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501


        :return: The reconnect_policies of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._reconnect_policies

    @reconnect_policies.setter
    def reconnect_policies(self, reconnect_policies):
        """Sets the reconnect_policies of this InlineResponse200106ResponseRemoteVpsaFeatures.


        :param reconnect_policies: The reconnect_policies of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._reconnect_policies = reconnect_policies

    @property
    def archival_pool(self):
        """Gets the archival_pool of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501


        :return: The archival_pool of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._archival_pool

    @archival_pool.setter
    def archival_pool(self, archival_pool):
        """Sets the archival_pool of this InlineResponse200106ResponseRemoteVpsaFeatures.


        :param archival_pool: The archival_pool of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._archival_pool = archival_pool

    @property
    def afa(self):
        """Gets the afa of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501


        :return: The afa of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._afa

    @afa.setter
    def afa(self, afa):
        """Sets the afa of this InlineResponse200106ResponseRemoteVpsaFeatures.


        :param afa: The afa of this InlineResponse200106ResponseRemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._afa = afa

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200106ResponseRemoteVpsaFeatures, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200106ResponseRemoteVpsaFeatures):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200106ResponseRemoteVpsaFeatures):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateCustomNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user': 'str',
        'name': 'str',
        'cidr': 'str',
        'ipv6_cidr': 'str',
        'gateway': 'str',
        'ipv6_gateway': 'str',
        'ip_range': 'str',
        'ipv6_ip_range': 'str',
        'vlan_id': 'int'
    }

    attribute_map = {
        'user': 'user',
        'name': 'name',
        'cidr': 'cidr',
        'ipv6_cidr': 'ipv6_cidr',
        'gateway': 'gateway',
        'ipv6_gateway': 'ipv6_gateway',
        'ip_range': 'ip_range',
        'ipv6_ip_range': 'ipv6_ip_range',
        'vlan_id': 'vlan_id'
    }

    def __init__(self, user=None, name=None, cidr=None, ipv6_cidr=None, gateway=None, ipv6_gateway=None, ip_range=None, ipv6_ip_range=None, vlan_id=None, _configuration=None):  # noqa: E501
        """CreateCustomNetwork - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._user = None
        self._name = None
        self._cidr = None
        self._ipv6_cidr = None
        self._gateway = None
        self._ipv6_gateway = None
        self._ip_range = None
        self._ipv6_ip_range = None
        self._vlan_id = None
        self.discriminator = None

        self.user = user
        self.name = name
        if cidr is not None:
            self.cidr = cidr
        if ipv6_cidr is not None:
            self.ipv6_cidr = ipv6_cidr
        self.gateway = gateway
        if ipv6_gateway is not None:
            self.ipv6_gateway = ipv6_gateway
        if ip_range is not None:
            self.ip_range = ip_range
        if ipv6_ip_range is not None:
            self.ipv6_ip_range = ipv6_ip_range
        if vlan_id is not None:
            self.vlan_id = vlan_id

    @property
    def user(self):
        """Gets the user of this CreateCustomNetwork.  # noqa: E501

        Tenant id  # noqa: E501

        :return: The user of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this CreateCustomNetwork.

        Tenant id  # noqa: E501

        :param user: The user of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def name(self):
        """Gets the name of this CreateCustomNetwork.  # noqa: E501


        :return: The name of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateCustomNetwork.


        :param name: The name of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def cidr(self):
        """Gets the cidr of this CreateCustomNetwork.  # noqa: E501


        :return: The cidr of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this CreateCustomNetwork.


        :param cidr: The cidr of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def ipv6_cidr(self):
        """Gets the ipv6_cidr of this CreateCustomNetwork.  # noqa: E501


        :return: The ipv6_cidr of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_cidr

    @ipv6_cidr.setter
    def ipv6_cidr(self, ipv6_cidr):
        """Sets the ipv6_cidr of this CreateCustomNetwork.


        :param ipv6_cidr: The ipv6_cidr of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_cidr = ipv6_cidr

    @property
    def gateway(self):
        """Gets the gateway of this CreateCustomNetwork.  # noqa: E501


        :return: The gateway of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this CreateCustomNetwork.


        :param gateway: The gateway of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gateway is None:
            raise ValueError("Invalid value for `gateway`, must not be `None`")  # noqa: E501

        self._gateway = gateway

    @property
    def ipv6_gateway(self):
        """Gets the ipv6_gateway of this CreateCustomNetwork.  # noqa: E501


        :return: The ipv6_gateway of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_gateway

    @ipv6_gateway.setter
    def ipv6_gateway(self, ipv6_gateway):
        """Sets the ipv6_gateway of this CreateCustomNetwork.


        :param ipv6_gateway: The ipv6_gateway of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_gateway = ipv6_gateway

    @property
    def ip_range(self):
        """Gets the ip_range of this CreateCustomNetwork.  # noqa: E501


        :return: The ip_range of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ip_range

    @ip_range.setter
    def ip_range(self, ip_range):
        """Sets the ip_range of this CreateCustomNetwork.


        :param ip_range: The ip_range of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """

        self._ip_range = ip_range

    @property
    def ipv6_ip_range(self):
        """Gets the ipv6_ip_range of this CreateCustomNetwork.  # noqa: E501


        :return: The ipv6_ip_range of this CreateCustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_ip_range

    @ipv6_ip_range.setter
    def ipv6_ip_range(self, ipv6_ip_range):
        """Sets the ipv6_ip_range of this CreateCustomNetwork.


        :param ipv6_ip_range: The ipv6_ip_range of this CreateCustomNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_ip_range = ipv6_ip_range

    @property
    def vlan_id(self):
        """Gets the vlan_id of this CreateCustomNetwork.  # noqa: E501

        To automatically assign use \"vlan_id\":\"\"  # noqa: E501

        :return: The vlan_id of this CreateCustomNetwork.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this CreateCustomNetwork.

        To automatically assign use \"vlan_id\":\"\"  # noqa: E501

        :param vlan_id: The vlan_id of this CreateCustomNetwork.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateCustomNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCustomNetwork):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateCustomNetwork):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateRemoteAuthenticationServer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domain': 'str',
        'domain_alias': 'str',
        'base': 'str',
        'type': 'str',
        'port': 'int',
        'dns': 'list[str]'
    }

    attribute_map = {
        'domain': 'domain',
        'domain_alias': 'domain_alias',
        'base': 'base',
        'type': 'type',
        'port': 'port',
        'dns': 'dns'
    }

    def __init__(self, domain=None, domain_alias=None, base=None, type=None, port=None, dns=None, _configuration=None):  # noqa: E501
        """CreateRemoteAuthenticationServer - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._domain = None
        self._domain_alias = None
        self._base = None
        self._type = None
        self._port = None
        self._dns = None
        self.discriminator = None

        self.domain = domain
        self.domain_alias = domain_alias
        self.base = base
        self.type = type
        if port is not None:
            self.port = port
        if dns is not None:
            self.dns = dns

    @property
    def domain(self):
        """Gets the domain of this CreateRemoteAuthenticationServer.  # noqa: E501


        :return: The domain of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CreateRemoteAuthenticationServer.


        :param domain: The domain of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and domain is None:
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def domain_alias(self):
        """Gets the domain_alias of this CreateRemoteAuthenticationServer.  # noqa: E501


        :return: The domain_alias of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: str
        """
        return self._domain_alias

    @domain_alias.setter
    def domain_alias(self, domain_alias):
        """Sets the domain_alias of this CreateRemoteAuthenticationServer.


        :param domain_alias: The domain_alias of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and domain_alias is None:
            raise ValueError("Invalid value for `domain_alias`, must not be `None`")  # noqa: E501

        self._domain_alias = domain_alias

    @property
    def base(self):
        """Gets the base of this CreateRemoteAuthenticationServer.  # noqa: E501


        :return: The base of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: str
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this CreateRemoteAuthenticationServer.


        :param base: The base of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and base is None:
            raise ValueError("Invalid value for `base`, must not be `None`")  # noqa: E501

        self._base = base

    @property
    def type(self):
        """Gets the type of this CreateRemoteAuthenticationServer.  # noqa: E501


        :return: The type of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateRemoteAuthenticationServer.


        :param type: The type of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def port(self):
        """Gets the port of this CreateRemoteAuthenticationServer.  # noqa: E501

        If not specified 389 is the default  # noqa: E501

        :return: The port of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this CreateRemoteAuthenticationServer.

        If not specified 389 is the default  # noqa: E501

        :param port: The port of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def dns(self):
        """Gets the dns of this CreateRemoteAuthenticationServer.  # noqa: E501


        :return: The dns of this CreateRemoteAuthenticationServer.  # noqa: E501
        :rtype: list[str]
        """
        return self._dns

    @dns.setter
    def dns(self, dns):
        """Sets the dns of this CreateRemoteAuthenticationServer.


        :param dns: The dns of this CreateRemoteAuthenticationServer.  # noqa: E501
        :type: list[str]
        """

        self._dns = dns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRemoteAuthenticationServer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRemoteAuthenticationServer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRemoteAuthenticationServer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.software_install_api import SoftwareInstallApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestSoftwareInstallApi(unittest.TestCase):
    """SoftwareInstallApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.software_install_api.SoftwareInstallApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_last_action(self):
        """Test case for abort_last_action

        """
        pass

    def test_cloud_upgrade(self):
        """Test case for cloud_upgrade

        """
        pass

    def test_download_package(self):
        """Test case for download_package

        """
        pass

    def test_erase_package(self):
        """Test case for erase_package

        """
        pass

    def test_list_packages(self):
        """Test case for list_packages

        """
        pass

    def test_list_sns(self):
        """Test case for list_sns

        """
        pass

    def test_register_images(self):
        """Test case for register_images

        """
        pass

    def test_restart_last_action(self):
        """Test case for restart_last_action

        """
        pass

    def test_show_all(self):
        """Test case for show_all

        """
        pass

    def test_sn_install(self):
        """Test case for sn_install

        """
        pass

    def test_upload_settings(self):
        """Test case for upload_settings

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20016CustomNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'user': 'str',
        'cidr': 'str',
        'gateway': 'str',
        'vlan_id': 'str',
        'id': 'str',
        'reserved': 'bool',
        'default_for_tenant': 'bool',
        'allocatable_ip_ranges': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'user': 'user',
        'cidr': 'cidr',
        'gateway': 'gateway',
        'vlan_id': 'vlan_id',
        'id': 'id',
        'reserved': 'reserved',
        'default_for_tenant': 'default_for_tenant',
        'allocatable_ip_ranges': 'allocatable_ip_ranges'
    }

    def __init__(self, name=None, user=None, cidr=None, gateway=None, vlan_id=None, id=None, reserved=None, default_for_tenant=None, allocatable_ip_ranges=None, _configuration=None):  # noqa: E501
        """InlineResponse20016CustomNetwork - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._user = None
        self._cidr = None
        self._gateway = None
        self._vlan_id = None
        self._id = None
        self._reserved = None
        self._default_for_tenant = None
        self._allocatable_ip_ranges = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if user is not None:
            self.user = user
        if cidr is not None:
            self.cidr = cidr
        if gateway is not None:
            self.gateway = gateway
        if vlan_id is not None:
            self.vlan_id = vlan_id
        if id is not None:
            self.id = id
        if reserved is not None:
            self.reserved = reserved
        if default_for_tenant is not None:
            self.default_for_tenant = default_for_tenant
        if allocatable_ip_ranges is not None:
            self.allocatable_ip_ranges = allocatable_ip_ranges

    @property
    def name(self):
        """Gets the name of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The name of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20016CustomNetwork.


        :param name: The name of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def user(self):
        """Gets the user of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The user of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this InlineResponse20016CustomNetwork.


        :param user: The user of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def cidr(self):
        """Gets the cidr of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The cidr of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this InlineResponse20016CustomNetwork.


        :param cidr: The cidr of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def gateway(self):
        """Gets the gateway of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The gateway of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this InlineResponse20016CustomNetwork.


        :param gateway: The gateway of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse20016CustomNetwork.


        :param vlan_id: The vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._vlan_id = vlan_id

    @property
    def id(self):
        """Gets the id of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20016CustomNetwork.


        :param id: The id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def reserved(self):
        """Gets the reserved of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The reserved of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._reserved

    @reserved.setter
    def reserved(self, reserved):
        """Sets the reserved of this InlineResponse20016CustomNetwork.


        :param reserved: The reserved of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: bool
        """

        self._reserved = reserved

    @property
    def default_for_tenant(self):
        """Gets the default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._default_for_tenant

    @default_for_tenant.setter
    def default_for_tenant(self, default_for_tenant):
        """Sets the default_for_tenant of this InlineResponse20016CustomNetwork.


        :param default_for_tenant: The default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: bool
        """

        self._default_for_tenant = default_for_tenant

    @property
    def allocatable_ip_ranges(self):
        """Gets the allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocatable_ip_ranges

    @allocatable_ip_ranges.setter
    def allocatable_ip_ranges(self, allocatable_ip_ranges):
        """Sets the allocatable_ip_ranges of this InlineResponse20016CustomNetwork.


        :param allocatable_ip_ranges: The allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: list[str]
        """

        self._allocatable_ip_ranges = allocatable_ip_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20016CustomNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20016CustomNetwork):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20016CustomNetwork):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import ProvisioningPortal
from ProvisioningPortal.api.vpsa_api import VPSAApi  # noqa: E501
from ProvisioningPortal.rest import ApiException


class TestVPSAApi(unittest.TestCase):
    """VPSAApi unit test stubs"""

    def setUp(self):
        self.api = ProvisioningPortal.api.vpsa_api.VPSAApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_proxy_vc_to_vpsa_object_storage(self):
        """Test case for add_proxy_vc_to_vpsa_object_storage

        """
        pass

    def test_add_storage_policy_to_vpsa_object_storage(self):
        """Test case for add_storage_policy_to_vpsa_object_storage

        """
        pass

    def test_add_storage_to_vpsa(self):
        """Test case for add_storage_to_vpsa

        """
        pass

    def test_add_virtual_network_vpsa(self):
        """Test case for add_virtual_network_vpsa

        """
        pass

    def test_assign_public_ip_vpsa(self):
        """Test case for assign_public_ip_vpsa

        """
        pass

    def test_change_vpsa_flash_cache_capacity(self):
        """Test case for change_vpsa_flash_cache_capacity

        """
        pass

    def test_change_vpsa_zadara_engine(self):
        """Test case for change_vpsa_zadara_engine

        """
        pass

    def test_create_object_storage_account(self):
        """Test case for create_object_storage_account

        """
        pass

    def test_create_vpsa(self):
        """Test case for create_vpsa

        """
        pass

    def test_delete_vpsa(self):
        """Test case for delete_vpsa

        """
        pass

    def test_disable_object_account_servce_from_vpsa_object_storage(self):
        """Test case for disable_object_account_servce_from_vpsa_object_storage

        """
        pass

    def test_disables_data_reduction_bundle_on_flash_vpsa(self):
        """Test case for disables_data_reduction_bundle_on_flash_vpsa

        """
        pass

    def test_enable_object_account_servce_for_vpsa_object_storage(self):
        """Test case for enable_object_account_servce_for_vpsa_object_storage

        """
        pass

    def test_enables_data_reduction_bundle_on_flash_vpsa(self):
        """Test case for enables_data_reduction_bundle_on_flash_vpsa

        """
        pass

    def test_get_object_account_servce_for_vpsa_object_storage(self):
        """Test case for get_object_account_servce_for_vpsa_object_storage

        """
        pass

    def test_get_object_storage_account_info(self):
        """Test case for get_object_storage_account_info

        """
        pass

    def test_get_vpsa_information(self):
        """Test case for get_vpsa_information

        """
        pass

    def test_get_vpsas_info(self):
        """Test case for get_vpsas_info

        """
        pass

    def test_hibernate_vpsa(self):
        """Test case for hibernate_vpsa

        """
        pass

    def test_list_compatible_vni_for_vpsa(self):
        """Test case for list_compatible_vni_for_vpsa

        """
        pass

    def test_list_object_storage_accounts_of_vpsa(self):
        """Test case for list_object_storage_accounts_of_vpsa

        """
        pass

    def test_maintenance_mode(self):
        """Test case for maintenance_mode

        """
        pass

    def test_remove_account_from_vpsa_object_storage(self):
        """Test case for remove_account_from_vpsa_object_storage

        """
        pass

    def test_remove_vni_from_vpsa(self):
        """Test case for remove_vni_from_vpsa

        """
        pass

    def test_remove_vpsa_public_ip(self):
        """Test case for remove_vpsa_public_ip

        """
        pass

    def test_resume_vpsa(self):
        """Test case for resume_vpsa

        """
        pass

    def test_update_object_account_service_for_vpsa_object_storage(self):
        """Test case for update_object_account_service_for_vpsa_object_storage

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.models.inline_response20086 import InlineResponse20086  # noqa: E501
from Vpsa.rest import ApiException


class TestInlineResponse20086(unittest.TestCase):
    """InlineResponse20086 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse20086(self):
        """Test InlineResponse20086"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Vpsa.models.inline_response20086.InlineResponse20086()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
